[![pipeline status](https://gitlab.com/marvin.vanaalst/moped/badges/master/pipeline.svg)](https://gitlab.com/marvin.vanaalst/moped/-/commits/master)
[![coverage report](https://gitlab.com/marvin.vanaalst/moped/badges/master/coverage.svg)](https://gitlab.com/marvin.vanaalst/moped/-/commits/master)
[![Documentation Status](https://readthedocs.org/projects/moped/badge/?version=latest)](https://moped.readthedocs.io/en/latest/?badge=latest)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# MOPED (Metabolic Object-oriented Python modelling Environment ?)

## Installation
Please consult our [installation tutorial](docs/source/installation-guide.md)

## Release notes
moped is currently in an alpha stage

## Documentation
The official documentation will be hosted on readthedocs

## Tutorials
For a tutorial check the [tutorial](docs/source/tutorial.ipynb) and
[reconstruction tutorial](docs/source/blast-reconstruction.ipynb)

## Troubleshooting
If you encounter any bugs, please first consult our [troubleshooting](docs/source/troubleshooting.md)
guide and if you cannot find an answer feel free to open an issue.


## Contributing
All contributions, bug reports, bug fixes, documentation improvements, enhancements and ideas are welcome.
If you want to contribute code to the project, please consider our [contribution guide](CONTRIBUTING.md)

## License
moped is licensed under [GPL 3](LICENSE)

## Issues and support
If you experience issues using the software please contact us through our [issues](https://gitlab.com/marvin.vanaalst/moped/issues) page.
